package %PACKAGE%;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.RectF;

public class Pop_Item {
	
	// position
	private float x;
	private float y;	
	
	private Paint paint = null;
	private String text;
	private Bitmap bitmap;	
	private Point itemSize;
	private State state;
	
	private int age = 0;
	private int life; // milliseconds 
		
	private float textOffset;
	
	private String type;
	
	private enum State {
		ALIVE,
		DYING,
		DEAD
	}
	
	// constructor
	Pop_Item(String text, PointF position, int life, Paint paint) {		
		Rect textBounds = new Rect(0,0,0,0);
		paint.getTextBounds(text, 0, text.length(), textBounds);		
		this.x = position.x;
		this.y = position.y;	
		this.text = text;
		this.paint = paint;
		this.life = life;
		this.state = State.ALIVE;
		this.age = 0;
		this.itemSize = new Point(textBounds.right, Math.abs(textBounds.bottom) + Math.abs(textBounds.top));;
		this.textOffset = this.paint.measureText(this.text) / 2;
		
		this.type = "text";
	}	
	
	// constructor
	Pop_Item(Bitmap bitmap, PointF position, int life) {		
		this.x = position.x;
		this.y = position.y;
		this.bitmap = bitmap;
		this.life = life;
		this.state = State.ALIVE;
		this.age = 0;
		this.itemSize = new Point(bitmap.getWidth(), bitmap.getHeight());
		
		this.type = "image";
	}	
	
	public void update(long elapsedTime) {		
		this.age += elapsedTime;
		
		if (this.paint != null) this.paint.setAlpha((int)(255 * (1 - (this.age / this.life))));
		
		if (this.age >= (long)this.life) this.state = State.DEAD;
	}
	
	public void draw(Canvas c) {
		if (this.state == State.ALIVE) {
			if (this.type.equals("text")) {
				c.drawText(this.text, this.x, this.y - (this.itemSize.y * this.age / this.life), this.paint);
			}
			else if (this.type.equals("image")) {
				c.drawBitmap(this.bitmap, this.x, this.y - (1.5f * this.itemSize.y * this.age / this.life), null);
			}
		}
	}
	
	public void setPosition(float newX, float newY) {
		this.x = newX;
		this.y = newY;
	}	
		
	public PointF getPos() {
		return new PointF(this.x, this.y);
	}
	
	public void setAliveState() {
		this.state = State.ALIVE;
	}
	
	public void setDyingState() {
		this.state = State.DYING;
	}
	
	public boolean isAlive(){
		return this.state != State.DEAD;
	}
}